Riego - Garden-Watering-System

- Using MQTT-Devices and MQTT-Server
- Linux Daemon with Webinterface
- Designed for running on embedded device like Raspberry
- Control from Cloud Server is possible
- Already in production for testing, but Work in progress
- Yet no documentation available
